#!/bin/csh

# HEPiX 3.9.10
# Copyright (C) 2003-2005 CERN
# Author: KELEMEN Peter <Peter.Kelemen@cern.ch>

# $Id: init,v 1.21 2008/04/02 07:44:22 fuji Exp $

if ( $?_HPX_SEEN_CORE_INIT ) then
	exit
endif
set _HPX_SEEN_CORE_INIT=1

set HPXB_CAT=/bin/cat
set HPXB_DATE=/bin/date
set HPXB_DOMAINNAME=/bin/domainname
set HPXB_EGREP=/bin/egrep
set HPXB_GREP=/bin/grep
set HPXB_LS=/bin/ls
set HPXB_MKDIR=/bin/mkdir
set HPXB_PS=/bin/ps
set HPXB_RM=/bin/rm
set HPXB_SED=/bin/sed
set HPXB_SLEEP=/bin/sleep
set HPXB_STTY=/bin/stty
set HPXB_TEST=/usr/bin/test
set HPXB_UNAME=/bin/uname

set HPXB_CUT=/usr/bin/cut
set HPXB_EXPR=/usr/bin/expr
set HPXB_NROFF=/usr/bin/nroff
set HPXB_ID=/usr/bin/id
set HPXB_TR=/usr/bin/tr
set HPXB_TSET=/usr/bin/tset
set HPXB_TTY=/usr/bin/tty
set HPXB_WHOAMI=/usr/bin/whoami
set HPXB_YPPASSWD=/usr/bin/yppasswd

set HPXB_MAILREG=/usr/local/bin/mailreg

set HPXB_ALIFETIME=/afs/usr/local/bin/alifetime

# Internal HEPiX variables.
set HPX_VERSION="3.9.10"
set HPX_INIT=""		# See end of this file.
set HPX_NONE=__NONE__
set HPX_HEPIX=""		# See hpx_is_hepix().
set HPX_ROOT=""			# See later.
set HPX_LOW_UID=""		# See later.
set HPX_AFS_HOME=""		# See later.
set HPX_UMASK=0022
set ETC=/etc/hepix		# HEPiX-X11 requires this.
set HPX_HOME=/etc/hepix/csh	# Legacy code was in /usr/local/lib/hepix/.
set HPX_HOME_CORE=$HPX_HOME/CORE
set HPX_HOME_HEP=$HPX_HOME/HEP
set HPX_HOME_SITE=$HPX_HOME/SITE
set HPX_SYSTEM_HOME=/etc/hepix	# legacy
set HPX_CLUSTER_HOME=$HPX_SYSTEM_HOME/cluster
set HPX_EXLIST=$HPX_SYSTEM_HOME/list-

# Determine user HEPiX home directory.
if ( $?HOME ) then
	if ( -d $HOME/.hepix ) then
		set HPX_USER_HOME=$HOME/.hepix
	else
		set HPX_USER_HOME=""
	endif
endif

# HEPiX off-button.
if ( "x$?HPX_USER_HOME" != x ) then
	if ( -r $HPX_USER_HOME/off ) then
		set HPX_HEPIX=OFF
	endif
endif

# Determine verbosity level.
if ( "x$?HPX_USER_HOME" != x ) then
	if ( -r $HPX_USER_HOME/verbose-level ) then
		set HPX_VERBOSE=`$HPXB_CAT $HPX_USER_HOME/verbose-level`
	else
		set HPX_VERBOSE=0
	endif
endif

# Determine debug level.
if ( "x$?HPX_USER_HOME" != x ) then
	if ( -r $HPX_USER_HOME/debug-level ) then
		set HPX_DEBUG=`$HPXB_CAT $HPX_USER_HOME/debug-level`
	else
		set HPX_DEBUG=0
	endif
endif

# Internal HEPiX variables set later
# HPX_SHELL
# HPX_USER
# HPX_UID

# Determine running shell.
set HPX_SHELL=csh
if ( $?tcsh ) then
	set HPX_SHELL=tcsh
endif

# Determine current user.
if ( ! $?USER && $?LOGNAME ) then
	setenv USER $LOGNAME
endif
if ( ! $?LOGNAME && $?USER ) then
	setenv LOGNAME $USER
endif
if ( ! $?USER ) then
	setenv USER `$HPXB_ID | $HPXB_SED -n 's/[^(]\{1,\}(\([^)]\{1,\}\)).*$/\1/p'`
endif
if ( ! $?USER ) then
	setenv USER `$HPXB_WHOAMI`
endif
if ( ! $?LOGNAME ) then
	setenv LOGNAME $USER
endif
set HPX_USER="$USER"
if ( $HPX_USER == root ) then
	set HPX_ROOT=YES
endif

# Determine current UID.
if ( $?uid ) then
	set HPX_UID=$uid
endif
if ( ! $?HPX_UID ) then
	set HPX_UID=`$HPXB_ID | $HPXB_SED -n 's/^uid=\([0-9]\{1,\}\).*$/\1/p'`
endif
if ( $HPX_UID < 100 ) then
	set HPX_LOW_UID=YES
endif

# Determine if user's $HOME is on AFS.
echo $HOME | $HPXB_GREP '^\/afs\/' > /dev/null
if ( $status == 0 ) then
	set HPX_AFS_HOME=YES
endif
	
# This is a Hack(tm), but a smart one nevertheless.  We are emulating shell
# functions (that are missing in csh(1) and derivatives) by using alias and
# script combinations.
set _HPX_SOURCE_CMD=csh
if ( $HPX_SHELL == tcsh ) then
	set _HPX_SOURCE_CMD=source
endif
alias hpx_is_hepix	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_is_hepix.csh "
if ( $_HPX_SOURCE_CMD == csh ) then
	# We have to make a compromise and not have the debugging
	# facilities of hpx_source.csh, since everything done in a subshell
	# will be lost when the shell it runs under exits.  In other words,
	# we can't modify our environment with subshells, so hpx_source()
	# is directly aliased to csh(1) source command.
	alias hpx_source	'if ( -r \!* ) source \!* '
else
	alias hpx_source 	"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_source.csh "
endif
alias hpx_echo		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_echo.csh "
alias hpx_debug		"$_HPX_SOURCE_CMD $HPX_HOME_CORE/hpx_debug.csh "

set HPX_INIT=YES

hpx_debug "csh flavour init done"

# vim: nowrap
# End of file.
