#!/bin/sh

# HEPiX 3.9.10
# Copyright (C) 2003-2005 CERN
# Author: KELEMEN Peter <Peter.Kelemen@cern.ch>

# $Id: init,v 1.25 2008/04/02 07:44:22 fuji Exp $

[ -n "$_HPX_SEEN_CORE_INIT" ] && return
_HPX_SEEN_CORE_INIT=1

# Binaries used by HEPiX.
HPXB_CAT=/bin/cat
HPXB_DATE=/bin/date
HPXB_DOMAINNAME=/bin/domainname
HPXB_EGREP=/bin/egrep
HPXB_GREP=/bin/grep
HPXB_LS=/bin/ls
HPXB_MKDIR=/bin/mkdir
HPXB_PS=/bin/ps
HPXB_RM=/bin/rm
HPXB_SED=/bin/sed
HPXB_SLEEP=/bin/sleep
HPXB_STTY=/bin/stty
HPXB_TEST=/usr/bin/test
HPXB_UNAME=/bin/uname

HPXB_CUT=/usr/bin/cut
HPXB_EXPR=/usr/bin/expr
HPXB_NROFF=/usr/bin/nroff
HPXB_ID=/usr/bin/id
HPXB_TR=/usr/bin/tr
HPXB_TSET=/usr/bin/tset
HPXB_TTY=/usr/bin/tty
HPXB_WHOAMI=/usr/bin/whoami
HPXB_YPPASSWD=/usr/bin/yppasswd

HPXB_MAILREG=/usr/local/bin/mailreg

HPXB_ALIFETIME=/afs/usr/local/bin/alifetime

# Internal HEPiX variables.
HPX_VERSION="3.9.10"
HPX_INIT=""		# See end of this file.
HPX_NONE=__NONE__
HPX_HEPIX=""		# See hpx_is_hepix().
HPX_ROOT=""		# See later.
HPX_LOW_UID=""		# See later.
HPX_AFS_HOME=""		# See later.
HPX_UMASK=0022
ETC=$HPX_HOME		# HEPiX-X11 requires this.
HPX_HOME=/etc/hepix/sh	# Legacy code was in /usr/local/lib/hepix/.
HPX_HOME_CORE=$HPX_HOME/CORE
HPX_HOME_HEP=$HPX_HOME/HEP
HPX_HOME_SITE=$HPX_HOME/SITE
HPX_SYSTEM_HOME=/etc/hepix	# legacy
HPX_CLUSTER_HOME=$HPX_SYSTEM_HOME/cluster
HPX_EXLIST=$HPX_SYSTEM_HOME/list-

# Determine user HEPiX home directory.
[ -n "$HOME" -a -d "$HOME/.hepix" ] \
	&& HPX_USER_HOME=$HOME/.hepix \
	|| HPX_USER_HOME=""

# HEPiX off-button.
if [ -n "$HPX_USER_HOME" -a -r "${HPX_USER_HOME}/off" ]; then
	HPX_HEPIX=OFF
fi

# Determine verbosity level.
[ -n "$HPX_USER_HOME" -a -r "$HPX_USER_HOME/verbose-level" ] \
	&& HPX_VERBOSE=`$HPXB_CAT $HPX_USER_HOME/verbose-level` \
	|| HPX_VERBOSE=0

# Determine debug level.
[ -n "$HPX_USER_HOME" -a -r "$HPX_USER_HOME/debug-level" ] \
	&& HPX_DEBUG=`$HPXB_CAT $HPX_USER_HOME/debug-level` \
	|| HPX_DEBUG=0

# Internal HEPiX variables set later
# HPX_SHELL
# HPX_USER
# HPX_UID

# Determine running shell.
HPX_SHELL=sh
[ -n "$FCEDIT" ] && HPX_SHELL=ksh
[ -n "$BASH_VERSION" ] && HPX_SHELL=bash
[ -n "$ZSH_VERSION" ] && HPX_SHELL=zsh

# Determine current user.
set -a
[ -z "$USER" -a -n "$LOGNAME" ] && USER=$LOGNAME
[ -z "$LOGNAME" -a -n "$USER" ] && LOGNAME=$USER
[ -z "$USER" ] && USER=`$HPXB_ID | $HPXB_SED -n 's/[^(]\{1,\}(\([^)]\{1,\}\)).*$/\1/p'`
[ -z "$USER" ] && USER=`$HPXB_WHOAMI`
[ -z "$LOGNAME" ] && LOGNAME=$USER
set +a
HPX_USER="$USER"
[ "$HPX_USER" = "root" ] && HPX_ROOT=YES

# Determine current UID.
HPX_UID="$UID"
[ -z "$UID" ] && HPX_UID=`$HPXB_ID | $HPXB_SED -n 's/^uid=\([0-9]\{1,\}\).*$/\1/p'`
[ $HPX_UID -lt 100 ] && HPX_LOW_UID=YES

# Determine if user's $HOME is on AFS.
echo $HOME | $HPXB_GREP '^\/afs\/' > /dev/null && HPX_AFS_HOME=YES 

# Determine whether HEPiX is to be run.
hpx_is_hepix () {
	[ "$HPX_HEPIX" = OFF ] && return 1
	[ "$HPX_HEPIX" = YES ] && return 1
	[ "$HPX_ROOT" = YES ] && return 1
	[ "$HPX_LOW_UID" = YES ] && return 1
	[ -r $HPX_EXLIST ] \
		&& $HPXB_GREP $HPX_USER $HPX_EXLIST 2>/dev/null >/dev/null \
		&& return 1
	HPX_HEPIX=YES
	return
}

hpx_source () {
	[ -z "$1" ] && return
	[ $HPX_VERBOSE -ge 13 ] && hpx_echo "N: CHECK $1"
	[ -r "$1" ] || return
	[ $HPX_VERBOSE -ge 11 ] && hpx_echo "N: -> SOURCE $1"
	. $1
	[ $HPX_VERBOSE -ge 12 ] && hpx_echo "N: PROCESSED $1"
}

hpx_echo () {
	[ -z "$1" ] && return
	echo "hepix: ${*}"
}

hpx_debug () {
	[ -z "$1" ] && return
	[ $HPX_DEBUG = 0 ] && return
	HPX_DATE=`$HPXB_DATE +'%Y-%m-%d %T'`
	hpx_echo "D: ${HPX_DATE} ${HPX_USER} "${HPX_SHELL}"["$$"] ("${SHLVL}"): ${*}"
}

HPX_INIT=YES

hpx_debug "sh flavour init done"

# vim: nowrap
# End of file.
